@@ -162,6 +162,16 @@ static inline void trysystem(const char *command)
   }
 }
 
+/* abort program if i is not a valid index in secarr */
+static void checkseci(const int i)
+{
+  if (i < SECMAX) {
+    return;
+  }
+  fprintf(stderr, "MKPROM2 ERROR: illegal section number %d. %d is the max.\n", i, SECMAX-1);
+  exit(3);
+}
+
 int main (argc, argv)
      int argc;
      char **argv;
@@ -1049,6 +1059,7 @@ int main (argc, argv)
         fprintf (dumpfile, "sections:\n");
         for (i = 0; i < secnum; i++)
           {
+	      checkseci(i);
 /* 	      if (entry && (i == 0)) */
 /* 	          fprintf (dumpfile, "\t.word\t0x%x\n", entry); */
 /* 	      else */
@@ -1767,6 +1778,7 @@ int main (argc, argv)
             for (i = 0; i < prefix_count; i++)
                 printf("\t%s-gcc\n", ccprefixes[i]);
             printf("\n");
+            printf("Please see the command line option -ccprefix <prefix> described in the MKPROM2 User's Manual.\n");
             exit(1);
         }
     }
@@ -2114,7 +2126,7 @@ void usage (char *argv0)
 	 puts("  -sdrambanks <num_banks> Set the number of populated SDRAM banks.\n\t\t\tDefault is 1.");
 	 puts("  -trfc <delay>\t\tSet the SDRAM tRFC parameter (in ns). Default is 66 ns.");
 	 puts("  -trp <delay>\t\tSet the SDRAM tRP parameter (in ns). Default is 20 ns.");
-	 puts("  -refresh <delay>\tSet the SDRAM refresh period (in us). Default is 7.8 us,\n\t\t\talthough many SDRAMS actually use 15.6 us.");
+	 puts("  -refresh <period>\tSet the SDRAM refresh period (in us). Default is 7.8 us.");
 	 puts("  -mcfg1 <hex>\t\tSet memory configuration register 1. Overwrites calculated value");
 	 puts("  -mcfg2 <hex>\t\tSet memory configuration register 2. Overwrites calculated value");
 	 puts("  -mcfg3 <hex>\t\tSet memory configuration register 3. Overwrites calculated value");
@@ -2562,6 +2574,7 @@ dumpsec (char *buf, int section_address, int section_size,
     } else {
         fprintf (dumpfile, "\t .text\n");
     }
+    checkseci(secnum);
     secarr[secnum].paddr = section_address;
     secarr[secnum].len = section_size;
     secarr[secnum].comp = comp;
